#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# Copyright (C) 2022, Jan-Philipp Litza (PLUTEX) <jpl@plutex.de>.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

# modifications by thl-cmk[at]outlook[dot]com
# 2024-02-21: changed import path form mk.gui.plugins.metrics to mk.gui.plugins.metrics.utils
#             added metrics/graph for unbound_unwanted_replies
#             moved to ~/local/lib/check_mk/gui/plugins/metrics (from local/share/check_mk/web/plugins/metrics)
#             added perfometer for unbound_answers (NOERROR/SERVFAIL) and unbound_unwanted_replies

from cmk.gui.i18n import _

from cmk.gui.plugins.metrics.utils import (
    metric_info,
    graph_info,
    perfometer_info,
)

metric_info['unbound_answers_NOERROR'] = {
    'title': _('Rate of NOERROR answers'),
    'unit': '1/s',
    'color': '31/a',
}

metric_info['unbound_answers_FORMERR'] = {
    'title': _('Rate of FORMERR answers'),
    'unit': '1/s',
    'color': '21/a',
}

metric_info['unbound_answers_SERVFAIL'] = {
    'title': _('Rate of SERVFAIL answers'),
    'unit': '1/s',
    'color': '11/a',
}

metric_info['unbound_answers_NXDOMAIN'] = {
    'title': _('Rate of NXDOMAIN answers'),
    'unit': '1/s',
    'color': '51/a',
}

metric_info['unbound_answers_NOTIMPL'] = {
    'title': _('Rate of NOTIMPL answers'),
    'unit': '1/s',
    'color': '41/a',
}

metric_info['unbound_answers_REFUSED'] = {
    'title': _('Rate of REFUSED answers'),
    'unit': '1/s',
    'color': '26/a',
}

metric_info['unbound_answers_nodata'] = {
    'title': _('Rate of answers without data'),
    'unit': '1/s',
    'color': '52/a',
}

graph_info['unbound_answers'] = {
    'title': _('Rate of answers'),
    'metrics': [
        (f'unbound_answers_{answer}', 'line')
        for answer in (
            'FORMERR',
            'NOERROR',
            'NOTIMPL',
            'NXDOMAIN',
            'REFUSED',
            'SERVFAIL',
            'nodata',
        )
    ],
}

perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'unbound_answers_NOERROR',
        'half_value': 100.0,  # ome year
        'exponent': 2,
    },
    {
        'type': 'logarithmic',
        'metric': 'unbound_answers_SERVFAIL',
        'half_value': 50.0,
        'exponent': 2,
    },
]))
