#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# Copyright (C) 2022, Jan-Philipp Litza (PLUTEX) <jpl@plutex.de>.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

# modifications by thl-cmk[at]outlook[dot]com
# 2024-02-21: changed import path form mk.gui.plugins.metrics to mk.gui.plugins.metrics.utils
#             added metrics/graph for unbound_unwanted_replies
#             moved to ~/local/lib/check_mk/gui/plugins/metrics (from local/share/check_mk/web/plugins/metrics)
#             added perfometer for unbound_answers (NOERROR/SERVFAIL) and unbound_unwanted_replies

from cmk.gui.i18n import _

from cmk.gui.plugins.metrics.utils import (
    metric_info,
    graph_info,
    perfometer_info,
)

metric_info['cache_hit_rate'] = {
    'title': _('Cache hits per second'),
    'unit': '1/s',
    'color': '26/a',
}

graph_info['cache_hit_misses'] = {
    'title': _('Cache Hits and Misses'),
    'metrics': [
        ('cache_hit_rate', 'line'),
        ('cache_misses_rate', 'line'),
    ],
}

metric_info['unbound_unwanted_replies'] = {
    'title': _('Unwanted replies'),
    'unit': '1/s',
    'color': '26/a',
}

graph_info['unbound_unwanted_replies'] = {
    'title': _('Unwanted replies'),
    'metrics': [
        ('unbound_unwanted_replies', 'area')
    ],
}

perfometer_info.append({
    'type': 'logarithmic',
    'metric': 'unbound_unwanted_replies',
    'half_value': 100.0,  # ome year
    'exponent': 2,
})
