#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : unbound_bakery.py
# File  : unbound_bakery.py

# 2024-04-21: fixed missing FixedValue in import
#             changed Alternative titles to "Upper levels in qps"/"Upper levels in %"
#             to better differentiate between them
#             added explicit unit "%2
#             added ruleset for bakery
#             renamed to unbound.py (from unbound_parameters.py)
#             moved to ~/local/lib/check_mk/gui/plugins/wato/check_parameters
#                   from local/share/check_mk/web/plugins/wato
# 2024-05-14: separated WATO for bakery and check in two files
# 2024-05-27: fixed crash in CRE version (has no cee elements)

try:
    from cmk.gui.cee.plugins.wato.agent_bakery.rulespecs.utils import RulespecGroupMonitoringAgentsAgentPlugins
except ModuleNotFoundError:
    pass
else:
    from cmk.gui.i18n import _
    from cmk.gui.plugins.wato.utils import HostRulespec, rulespec_registry
    from cmk.gui.valuespec import Alternative, Dictionary, FixedValue, TextInput


    def _parameter_valuespec_unbound_bakery():
        return Alternative(
            title='Unbound',
            elements=[
                Dictionary(
                    title='Deploy the unbound agent plugin',
                    required_keys=['deploy_plugin'],
                    elements=[
                        ('config_file_path',
                         TextInput(
                             title=_('Path of config file'),
                             size=100,
                             allow_empty=False,
                             placeholder='/etc/unbound/unbound.conf',
                         )),
                        ('deploy_plugin',
                         FixedValue(
                             True,
                             title=_('Deploy unbound plugin'),
                             totext='Yes',
                         ))
                    ]),
                FixedValue(
                    None,
                    title=_('Do not deploy the unbound agent plugin'),
                    totext=_('The unbound agent plugin will not be deployed')
                ),
            ]
        )


    rulespec_registry.register(
        HostRulespec(
            group=RulespecGroupMonitoringAgentsAgentPlugins,
            name='agent_config:unbound',
            valuespec=_parameter_valuespec_unbound_bakery,
        )
    )
